AutoTimestamp

Enum AutoTimestamp 

pub enum AutoTimestamp {
    Created,
    Updated,
}
Marks a column as automatically set on insert and/or update (e.g. created_at, updated_at).

Variants



Created

Set once when the row is inserted (e.g. created_at).



Updated

Set on insert and updated on every update (e.g. updated_at).