Plugin API interface trait
This trait abstracts the Plugin API so that plugins can work with any implementation. The concrete implementation in the core app provides access to Database and ExtensionRegistry.
Traits
- PluginAPI
Interface - Abstract interface for plugins to interact with Core